@@ -7,14 +7,16 @@
 # Licensed under the MIT license:
 # http://www.opensource.org/licenses/MIT-license
 # Copyright (c) 2016, Andrew Backes <backes.andrew@gmail.com>
-# Copyright (c) 2022, Paolo D'Alessandro <pole.gamedev@@gmail.com>
+# Copyright (c) 2022, Paolo D'Alessandro <pole.gamedev@gmail.com>
 
+from pokemontcgsdkasync.asyncclientcontext import AsyncClientContext
+from pokemontcgsdkasync.pokemontcgexception import PokemonTcgException
+from pokemontcgsdkasync.query import SingleQuery, MultipleQuery, ArrayQuery
+from pokemontcgsdkasync.querybuilder import QueryBuilder
 from pokemontcgsdkasync.card import Card
 from pokemontcgsdkasync.set import Set
 from pokemontcgsdkasync.subtype import Subtype
 from pokemontcgsdkasync.supertype import Supertype
 from pokemontcgsdkasync.type import Type
 from pokemontcgsdkasync.rarity import Rarity
-from pokemontcgsdkasync.asyncclientcontext import AsyncClientContext
-from pokemontcgsdkasync.asyncclientcontext import PokemonTcgException
-from pokemontcgsdkasync.querybuilder import QueryBuilder
+
