@@ -1,3 +1,4 @@
+from pokemontcgsdkasync.query import ArrayQuery
 from pokemontcgsdkasync.querybuilder import QueryBuilder
 
 
@@ -5,5 +6,5 @@ class Subtype:
     RESOURCE = 'subtypes'
 
     @staticmethod
-    def all():
+    def all() -> ArrayQuery:
         return QueryBuilder(Subtype).array()
