@@ -1,3 +1,4 @@
+from pokemontcgsdkasync.query import ArrayQuery
 from pokemontcgsdkasync.querybuilder import QueryBuilder
 
 
@@ -5,5 +6,5 @@ class Supertype:
     RESOURCE = 'supertypes'
 
     @staticmethod
-    def all():
+    def all() -> ArrayQuery:
         return QueryBuilder(Supertype).array()
