@@ -8,7 +8,7 @@ class TestSubtype(unittest.IsolatedAsyncioTestCase):
 
     async def test_all_returns_subtypes(self):
         async with AsyncClientContext():
-            subtypes: List[Subtype] = await Subtype.all()
+            subtypes: List[Subtype] = await Subtype.all().get()
 
             self.assertTrue(len(subtypes) > 15)
             self.assertTrue('MEGA' in subtypes)
