@@ -8,6 +8,6 @@ class TestSupertype(unittest.IsolatedAsyncioTestCase):
 
     async def test_all_returns_supertypes(self):
         async with AsyncClientContext():
-            supertypes: List[Supertype] = await Supertype.all()
+            supertypes: List[Supertype] = await Supertype.all().get()
 
             self.assertEqual(["Energy", "Pokémon", "Trainer"], supertypes)
