@@ -8,7 +8,7 @@ class TestType(unittest.IsolatedAsyncioTestCase):
 
     async def test_all_returns_types(self):
         async with AsyncClientContext():
-            types: List[Type] = await Type.all()
+            types: List[Type] = await Type.all().get()
 
             self.assertEqual(
                 ["Colorless", "Darkness", "Dragon", "Fairy", "Fighting", "Fire", "Grass", "Lightning", "Metal",
